using Godot;
using Godot.NativeInterop;

partial class ExportedFields
{
#pragma warning disable CS0109 // Disable warning about redundant 'new' keyword
    /// <summary>
    /// Cached StringNames for the properties and fields contained in this class, for fast lookup.
    /// </summary>
    public new class PropertyName : global::Godot.GodotObject.PropertyName {
        /// <summary>
        /// Cached name for the '_fieldBoolean' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldBoolean = "_fieldBoolean";
        /// <summary>
        /// Cached name for the '_fieldChar' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldChar = "_fieldChar";
        /// <summary>
        /// Cached name for the '_fieldSByte' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldSByte = "_fieldSByte";
        /// <summary>
        /// Cached name for the '_fieldInt16' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldInt16 = "_fieldInt16";
        /// <summary>
        /// Cached name for the '_fieldInt32' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldInt32 = "_fieldInt32";
        /// <summary>
        /// Cached name for the '_fieldInt64' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldInt64 = "_fieldInt64";
        /// <summary>
        /// Cached name for the '_fieldByte' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldByte = "_fieldByte";
        /// <summary>
        /// Cached name for the '_fieldUInt16' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldUInt16 = "_fieldUInt16";
        /// <summary>
        /// Cached name for the '_fieldUInt32' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldUInt32 = "_fieldUInt32";
        /// <summary>
        /// Cached name for the '_fieldUInt64' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldUInt64 = "_fieldUInt64";
        /// <summary>
        /// Cached name for the '_fieldSingle' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldSingle = "_fieldSingle";
        /// <summary>
        /// Cached name for the '_fieldDouble' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldDouble = "_fieldDouble";
        /// <summary>
        /// Cached name for the '_fieldString' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldString = "_fieldString";
        /// <summary>
        /// Cached name for the '_fieldStaticImport' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldStaticImport = "_fieldStaticImport";
        /// <summary>
        /// Cached name for the '_fieldVector2' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldVector2 = "_fieldVector2";
        /// <summary>
        /// Cached name for the '_fieldVector2I' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldVector2I = "_fieldVector2I";
        /// <summary>
        /// Cached name for the '_fieldRect2' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldRect2 = "_fieldRect2";
        /// <summary>
        /// Cached name for the '_fieldRect2I' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldRect2I = "_fieldRect2I";
        /// <summary>
        /// Cached name for the '_fieldTransform2D' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldTransform2D = "_fieldTransform2D";
        /// <summary>
        /// Cached name for the '_fieldVector3' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldVector3 = "_fieldVector3";
        /// <summary>
        /// Cached name for the '_fieldVector3I' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldVector3I = "_fieldVector3I";
        /// <summary>
        /// Cached name for the '_fieldBasis' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldBasis = "_fieldBasis";
        /// <summary>
        /// Cached name for the '_fieldQuaternion' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldQuaternion = "_fieldQuaternion";
        /// <summary>
        /// Cached name for the '_fieldTransform3D' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldTransform3D = "_fieldTransform3D";
        /// <summary>
        /// Cached name for the '_fieldVector4' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldVector4 = "_fieldVector4";
        /// <summary>
        /// Cached name for the '_fieldVector4I' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldVector4I = "_fieldVector4I";
        /// <summary>
        /// Cached name for the '_fieldProjection' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldProjection = "_fieldProjection";
        /// <summary>
        /// Cached name for the '_fieldAabb' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldAabb = "_fieldAabb";
        /// <summary>
        /// Cached name for the '_fieldColor' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldColor = "_fieldColor";
        /// <summary>
        /// Cached name for the '_fieldPlane' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldPlane = "_fieldPlane";
        /// <summary>
        /// Cached name for the '_fieldCallable' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldCallable = "_fieldCallable";
        /// <summary>
        /// Cached name for the '_fieldSignal' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldSignal = "_fieldSignal";
        /// <summary>
        /// Cached name for the '_fieldEnum' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldEnum = "_fieldEnum";
        /// <summary>
        /// Cached name for the '_fieldFlagsEnum' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldFlagsEnum = "_fieldFlagsEnum";
        /// <summary>
        /// Cached name for the '_fieldByteArray' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldByteArray = "_fieldByteArray";
        /// <summary>
        /// Cached name for the '_fieldInt32Array' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldInt32Array = "_fieldInt32Array";
        /// <summary>
        /// Cached name for the '_fieldInt64Array' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldInt64Array = "_fieldInt64Array";
        /// <summary>
        /// Cached name for the '_fieldSingleArray' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldSingleArray = "_fieldSingleArray";
        /// <summary>
        /// Cached name for the '_fieldDoubleArray' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldDoubleArray = "_fieldDoubleArray";
        /// <summary>
        /// Cached name for the '_fieldStringArray' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldStringArray = "_fieldStringArray";
        /// <summary>
        /// Cached name for the '_fieldStringArrayEnum' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldStringArrayEnum = "_fieldStringArrayEnum";
        /// <summary>
        /// Cached name for the '_fieldVector2Array' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldVector2Array = "_fieldVector2Array";
        /// <summary>
        /// Cached name for the '_fieldVector3Array' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldVector3Array = "_fieldVector3Array";
        /// <summary>
        /// Cached name for the '_fieldColorArray' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldColorArray = "_fieldColorArray";
        /// <summary>
        /// Cached name for the '_fieldGodotObjectOrDerivedArray' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldGodotObjectOrDerivedArray = "_fieldGodotObjectOrDerivedArray";
        /// <summary>
        /// Cached name for the '_fieldStringNameArray' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldStringNameArray = "_fieldStringNameArray";
        /// <summary>
        /// Cached name for the '_fieldNodePathArray' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldNodePathArray = "_fieldNodePathArray";
        /// <summary>
        /// Cached name for the '_fieldRidArray' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldRidArray = "_fieldRidArray";
        /// <summary>
        /// Cached name for the '_fieldEmptyInt32Array' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldEmptyInt32Array = "_fieldEmptyInt32Array";
        /// <summary>
        /// Cached name for the '_fieldArrayFromList' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldArrayFromList = "_fieldArrayFromList";
        /// <summary>
        /// Cached name for the '_fieldVariant' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldVariant = "_fieldVariant";
        /// <summary>
        /// Cached name for the '_fieldGodotObjectOrDerived' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldGodotObjectOrDerived = "_fieldGodotObjectOrDerived";
        /// <summary>
        /// Cached name for the '_fieldGodotResourceTexture' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldGodotResourceTexture = "_fieldGodotResourceTexture";
        /// <summary>
        /// Cached name for the '_fieldGodotResourceTextureWithInitializer' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldGodotResourceTextureWithInitializer = "_fieldGodotResourceTextureWithInitializer";
        /// <summary>
        /// Cached name for the '_fieldStringName' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldStringName = "_fieldStringName";
        /// <summary>
        /// Cached name for the '_fieldNodePath' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldNodePath = "_fieldNodePath";
        /// <summary>
        /// Cached name for the '_fieldRid' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldRid = "_fieldRid";
        /// <summary>
        /// Cached name for the '_fieldGodotDictionary' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldGodotDictionary = "_fieldGodotDictionary";
        /// <summary>
        /// Cached name for the '_fieldGodotArray' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldGodotArray = "_fieldGodotArray";
        /// <summary>
        /// Cached name for the '_fieldGodotGenericDictionary' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldGodotGenericDictionary = "_fieldGodotGenericDictionary";
        /// <summary>
        /// Cached name for the '_fieldGodotGenericArray' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldGodotGenericArray = "_fieldGodotGenericArray";
        /// <summary>
        /// Cached name for the '_fieldEmptyInt64Array' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fieldEmptyInt64Array = "_fieldEmptyInt64Array";
    }
    /// <inheritdoc/>
    [global::System.ComponentModel.EditorBrowsable(global::System.ComponentModel.EditorBrowsableState.Never)]
    protected override bool SetGodotClassPropertyValue(in godot_string_name name, in godot_variant value)
    {
        if (name == PropertyName.@_fieldBoolean) {
            this.@_fieldBoolean = global::Godot.NativeInterop.VariantUtils.ConvertTo<bool>(value);
            return true;
        }
        if (name == PropertyName.@_fieldChar) {
            this.@_fieldChar = global::Godot.NativeInterop.VariantUtils.ConvertTo<char>(value);
            return true;
        }
        if (name == PropertyName.@_fieldSByte) {
            this.@_fieldSByte = global::Godot.NativeInterop.VariantUtils.ConvertTo<sbyte>(value);
            return true;
        }
        if (name == PropertyName.@_fieldInt16) {
            this.@_fieldInt16 = global::Godot.NativeInterop.VariantUtils.ConvertTo<short>(value);
            return true;
        }
        if (name == PropertyName.@_fieldInt32) {
            this.@_fieldInt32 = global::Godot.NativeInterop.VariantUtils.ConvertTo<int>(value);
            return true;
        }
        if (name == PropertyName.@_fieldInt64) {
            this.@_fieldInt64 = global::Godot.NativeInterop.VariantUtils.ConvertTo<long>(value);
            return true;
        }
        if (name == PropertyName.@_fieldByte) {
            this.@_fieldByte = global::Godot.NativeInterop.VariantUtils.ConvertTo<byte>(value);
            return true;
        }
        if (name == PropertyName.@_fieldUInt16) {
            this.@_fieldUInt16 = global::Godot.NativeInterop.VariantUtils.ConvertTo<ushort>(value);
            return true;
        }
        if (name == PropertyName.@_fieldUInt32) {
            this.@_fieldUInt32 = global::Godot.NativeInterop.VariantUtils.ConvertTo<uint>(value);
            return true;
        }
        if (name == PropertyName.@_fieldUInt64) {
            this.@_fieldUInt64 = global::Godot.NativeInterop.VariantUtils.ConvertTo<ulong>(value);
            return true;
        }
        if (name == PropertyName.@_fieldSingle) {
            this.@_fieldSingle = global::Godot.NativeInterop.VariantUtils.ConvertTo<float>(value);
            return true;
        }
        if (name == PropertyName.@_fieldDouble) {
            this.@_fieldDouble = global::Godot.NativeInterop.VariantUtils.ConvertTo<double>(value);
            return true;
        }
        if (name == PropertyName.@_fieldString) {
            this.@_fieldString = global::Godot.NativeInterop.VariantUtils.ConvertTo<string>(value);
            return true;
        }
        if (name == PropertyName.@_fieldStaticImport) {
            this.@_fieldStaticImport = global::Godot.NativeInterop.VariantUtils.ConvertTo<float>(value);
            return true;
        }
        if (name == PropertyName.@_fieldVector2) {
            this.@_fieldVector2 = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Vector2>(value);
            return true;
        }
        if (name == PropertyName.@_fieldVector2I) {
            this.@_fieldVector2I = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Vector2I>(value);
            return true;
        }
        if (name == PropertyName.@_fieldRect2) {
            this.@_fieldRect2 = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Rect2>(value);
            return true;
        }
        if (name == PropertyName.@_fieldRect2I) {
            this.@_fieldRect2I = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Rect2I>(value);
            return true;
        }
        if (name == PropertyName.@_fieldTransform2D) {
            this.@_fieldTransform2D = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Transform2D>(value);
            return true;
        }
        if (name == PropertyName.@_fieldVector3) {
            this.@_fieldVector3 = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Vector3>(value);
            return true;
        }
        if (name == PropertyName.@_fieldVector3I) {
            this.@_fieldVector3I = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Vector3I>(value);
            return true;
        }
        if (name == PropertyName.@_fieldBasis) {
            this.@_fieldBasis = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Basis>(value);
            return true;
        }
        if (name == PropertyName.@_fieldQuaternion) {
            this.@_fieldQuaternion = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Quaternion>(value);
            return true;
        }
        if (name == PropertyName.@_fieldTransform3D) {
            this.@_fieldTransform3D = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Transform3D>(value);
            return true;
        }
        if (name == PropertyName.@_fieldVector4) {
            this.@_fieldVector4 = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Vector4>(value);
            return true;
        }
        if (name == PropertyName.@_fieldVector4I) {
            this.@_fieldVector4I = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Vector4I>(value);
            return true;
        }
        if (name == PropertyName.@_fieldProjection) {
            this.@_fieldProjection = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Projection>(value);
            return true;
        }
        if (name == PropertyName.@_fieldAabb) {
            this.@_fieldAabb = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Aabb>(value);
            return true;
        }
        if (name == PropertyName.@_fieldColor) {
            this.@_fieldColor = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Color>(value);
            return true;
        }
        if (name == PropertyName.@_fieldPlane) {
            this.@_fieldPlane = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Plane>(value);
            return true;
        }
        if (name == PropertyName.@_fieldCallable) {
            this.@_fieldCallable = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Callable>(value);
            return true;
        }
        if (name == PropertyName.@_fieldSignal) {
            this.@_fieldSignal = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Signal>(value);
            return true;
        }
        if (name == PropertyName.@_fieldEnum) {
            this.@_fieldEnum = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::ExportedFields.MyEnum>(value);
            return true;
        }
        if (name == PropertyName.@_fieldFlagsEnum) {
            this.@_fieldFlagsEnum = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::ExportedFields.MyFlagsEnum>(value);
            return true;
        }
        if (name == PropertyName.@_fieldByteArray) {
            this.@_fieldByteArray = global::Godot.NativeInterop.VariantUtils.ConvertTo<byte[]>(value);
            return true;
        }
        if (name == PropertyName.@_fieldInt32Array) {
            this.@_fieldInt32Array = global::Godot.NativeInterop.VariantUtils.ConvertTo<int[]>(value);
            return true;
        }
        if (name == PropertyName.@_fieldInt64Array) {
            this.@_fieldInt64Array = global::Godot.NativeInterop.VariantUtils.ConvertTo<long[]>(value);
            return true;
        }
        if (name == PropertyName.@_fieldSingleArray) {
            this.@_fieldSingleArray = global::Godot.NativeInterop.VariantUtils.ConvertTo<float[]>(value);
            return true;
        }
        if (name == PropertyName.@_fieldDoubleArray) {
            this.@_fieldDoubleArray = global::Godot.NativeInterop.VariantUtils.ConvertTo<double[]>(value);
            return true;
        }
        if (name == PropertyName.@_fieldStringArray) {
            this.@_fieldStringArray = global::Godot.NativeInterop.VariantUtils.ConvertTo<string[]>(value);
            return true;
        }
        if (name == PropertyName.@_fieldStringArrayEnum) {
            this.@_fieldStringArrayEnum = global::Godot.NativeInterop.VariantUtils.ConvertTo<string[]>(value);
            return true;
        }
        if (name == PropertyName.@_fieldVector2Array) {
            this.@_fieldVector2Array = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Vector2[]>(value);
            return true;
        }
        if (name == PropertyName.@_fieldVector3Array) {
            this.@_fieldVector3Array = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Vector3[]>(value);
            return true;
        }
        if (name == PropertyName.@_fieldColorArray) {
            this.@_fieldColorArray = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Color[]>(value);
            return true;
        }
        if (name == PropertyName.@_fieldGodotObjectOrDerivedArray) {
            this.@_fieldGodotObjectOrDerivedArray = global::Godot.NativeInterop.VariantUtils.ConvertToSystemArrayOfGodotObject<global::Godot.GodotObject>(value);
            return true;
        }
        if (name == PropertyName.@_fieldStringNameArray) {
            this.@_fieldStringNameArray = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.StringName[]>(value);
            return true;
        }
        if (name == PropertyName.@_fieldNodePathArray) {
            this.@_fieldNodePathArray = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.NodePath[]>(value);
            return true;
        }
        if (name == PropertyName.@_fieldRidArray) {
            this.@_fieldRidArray = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Rid[]>(value);
            return true;
        }
        if (name == PropertyName.@_fieldEmptyInt32Array) {
            this.@_fieldEmptyInt32Array = global::Godot.NativeInterop.VariantUtils.ConvertTo<int[]>(value);
            return true;
        }
        if (name == PropertyName.@_fieldArrayFromList) {
            this.@_fieldArrayFromList = global::Godot.NativeInterop.VariantUtils.ConvertTo<int[]>(value);
            return true;
        }
        if (name == PropertyName.@_fieldVariant) {
            this.@_fieldVariant = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Variant>(value);
            return true;
        }
        if (name == PropertyName.@_fieldGodotObjectOrDerived) {
            this.@_fieldGodotObjectOrDerived = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.GodotObject>(value);
            return true;
        }
        if (name == PropertyName.@_fieldGodotResourceTexture) {
            this.@_fieldGodotResourceTexture = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Texture>(value);
            return true;
        }
        if (name == PropertyName.@_fieldGodotResourceTextureWithInitializer) {
            this.@_fieldGodotResourceTextureWithInitializer = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Texture>(value);
            return true;
        }
        if (name == PropertyName.@_fieldStringName) {
            this.@_fieldStringName = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.StringName>(value);
            return true;
        }
        if (name == PropertyName.@_fieldNodePath) {
            this.@_fieldNodePath = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.NodePath>(value);
            return true;
        }
        if (name == PropertyName.@_fieldRid) {
            this.@_fieldRid = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Rid>(value);
            return true;
        }
        if (name == PropertyName.@_fieldGodotDictionary) {
            this.@_fieldGodotDictionary = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Collections.Dictionary>(value);
            return true;
        }
        if (name == PropertyName.@_fieldGodotArray) {
            this.@_fieldGodotArray = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Collections.Array>(value);
            return true;
        }
        if (name == PropertyName.@_fieldGodotGenericDictionary) {
            this.@_fieldGodotGenericDictionary = global::Godot.NativeInterop.VariantUtils.ConvertToDictionary<string, bool>(value);
            return true;
        }
        if (name == PropertyName.@_fieldGodotGenericArray) {
            this.@_fieldGodotGenericArray = global::Godot.NativeInterop.VariantUtils.ConvertToArray<int>(value);
            return true;
        }
        if (name == PropertyName.@_fieldEmptyInt64Array) {
            this.@_fieldEmptyInt64Array = global::Godot.NativeInterop.VariantUtils.ConvertTo<long[]>(value);
            return true;
        }
        return base.SetGodotClassPropertyValue(name, value);
    }
    /// <inheritdoc/>
    [global::System.ComponentModel.EditorBrowsable(global::System.ComponentModel.EditorBrowsableState.Never)]
    protected override bool GetGodotClassPropertyValue(in godot_string_name name, out godot_variant value)
    {
        if (name == PropertyName.@_fieldBoolean) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<bool>(this.@_fieldBoolean);
            return true;
        }
        if (name == PropertyName.@_fieldChar) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<char>(this.@_fieldChar);
            return true;
        }
        if (name == PropertyName.@_fieldSByte) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<sbyte>(this.@_fieldSByte);
            return true;
        }
        if (name == PropertyName.@_fieldInt16) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<short>(this.@_fieldInt16);
            return true;
        }
        if (name == PropertyName.@_fieldInt32) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<int>(this.@_fieldInt32);
            return true;
        }
        if (name == PropertyName.@_fieldInt64) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<long>(this.@_fieldInt64);
            return true;
        }
        if (name == PropertyName.@_fieldByte) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<byte>(this.@_fieldByte);
            return true;
        }
        if (name == PropertyName.@_fieldUInt16) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<ushort>(this.@_fieldUInt16);
            return true;
        }
        if (name == PropertyName.@_fieldUInt32) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<uint>(this.@_fieldUInt32);
            return true;
        }
        if (name == PropertyName.@_fieldUInt64) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<ulong>(this.@_fieldUInt64);
            return true;
        }
        if (name == PropertyName.@_fieldSingle) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<float>(this.@_fieldSingle);
            return true;
        }
        if (name == PropertyName.@_fieldDouble) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<double>(this.@_fieldDouble);
            return true;
        }
        if (name == PropertyName.@_fieldString) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<string>(this.@_fieldString);
            return true;
        }
        if (name == PropertyName.@_fieldStaticImport) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<float>(this.@_fieldStaticImport);
            return true;
        }
        if (name == PropertyName.@_fieldVector2) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Vector2>(this.@_fieldVector2);
            return true;
        }
        if (name == PropertyName.@_fieldVector2I) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Vector2I>(this.@_fieldVector2I);
            return true;
        }
        if (name == PropertyName.@_fieldRect2) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Rect2>(this.@_fieldRect2);
            return true;
        }
        if (name == PropertyName.@_fieldRect2I) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Rect2I>(this.@_fieldRect2I);
            return true;
        }
        if (name == PropertyName.@_fieldTransform2D) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Transform2D>(this.@_fieldTransform2D);
            return true;
        }
        if (name == PropertyName.@_fieldVector3) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Vector3>(this.@_fieldVector3);
            return true;
        }
        if (name == PropertyName.@_fieldVector3I) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Vector3I>(this.@_fieldVector3I);
            return true;
        }
        if (name == PropertyName.@_fieldBasis) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Basis>(this.@_fieldBasis);
            return true;
        }
        if (name == PropertyName.@_fieldQuaternion) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Quaternion>(this.@_fieldQuaternion);
            return true;
        }
        if (name == PropertyName.@_fieldTransform3D) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Transform3D>(this.@_fieldTransform3D);
            return true;
        }
        if (name == PropertyName.@_fieldVector4) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Vector4>(this.@_fieldVector4);
            return true;
        }
        if (name == PropertyName.@_fieldVector4I) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Vector4I>(this.@_fieldVector4I);
            return true;
        }
        if (name == PropertyName.@_fieldProjection) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Projection>(this.@_fieldProjection);
            return true;
        }
        if (name == PropertyName.@_fieldAabb) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Aabb>(this.@_fieldAabb);
            return true;
        }
        if (name == PropertyName.@_fieldColor) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Color>(this.@_fieldColor);
            return true;
        }
        if (name == PropertyName.@_fieldPlane) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Plane>(this.@_fieldPlane);
            return true;
        }
        if (name == PropertyName.@_fieldCallable) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Callable>(this.@_fieldCallable);
            return true;
        }
        if (name == PropertyName.@_fieldSignal) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Signal>(this.@_fieldSignal);
            return true;
        }
        if (name == PropertyName.@_fieldEnum) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::ExportedFields.MyEnum>(this.@_fieldEnum);
            return true;
        }
        if (name == PropertyName.@_fieldFlagsEnum) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::ExportedFields.MyFlagsEnum>(this.@_fieldFlagsEnum);
            return true;
        }
        if (name == PropertyName.@_fieldByteArray) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<byte[]>(this.@_fieldByteArray);
            return true;
        }
        if (name == PropertyName.@_fieldInt32Array) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<int[]>(this.@_fieldInt32Array);
            return true;
        }
        if (name == PropertyName.@_fieldInt64Array) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<long[]>(this.@_fieldInt64Array);
            return true;
        }
        if (name == PropertyName.@_fieldSingleArray) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<float[]>(this.@_fieldSingleArray);
            return true;
        }
        if (name == PropertyName.@_fieldDoubleArray) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<double[]>(this.@_fieldDoubleArray);
            return true;
        }
        if (name == PropertyName.@_fieldStringArray) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<string[]>(this.@_fieldStringArray);
            return true;
        }
        if (name == PropertyName.@_fieldStringArrayEnum) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<string[]>(this.@_fieldStringArrayEnum);
            return true;
        }
        if (name == PropertyName.@_fieldVector2Array) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Vector2[]>(this.@_fieldVector2Array);
            return true;
        }
        if (name == PropertyName.@_fieldVector3Array) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Vector3[]>(this.@_fieldVector3Array);
            return true;
        }
        if (name == PropertyName.@_fieldColorArray) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Color[]>(this.@_fieldColorArray);
            return true;
        }
        if (name == PropertyName.@_fieldGodotObjectOrDerivedArray) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFromSystemArrayOfGodotObject(this.@_fieldGodotObjectOrDerivedArray);
            return true;
        }
        if (name == PropertyName.@_fieldStringNameArray) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.StringName[]>(this.@_fieldStringNameArray);
            return true;
        }
        if (name == PropertyName.@_fieldNodePathArray) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.NodePath[]>(this.@_fieldNodePathArray);
            return true;
        }
        if (name == PropertyName.@_fieldRidArray) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Rid[]>(this.@_fieldRidArray);
            return true;
        }
        if (name == PropertyName.@_fieldEmptyInt32Array) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<int[]>(this.@_fieldEmptyInt32Array);
            return true;
        }
        if (name == PropertyName.@_fieldArrayFromList) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<int[]>(this.@_fieldArrayFromList);
            return true;
        }
        if (name == PropertyName.@_fieldVariant) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Variant>(this.@_fieldVariant);
            return true;
        }
        if (name == PropertyName.@_fieldGodotObjectOrDerived) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.GodotObject>(this.@_fieldGodotObjectOrDerived);
            return true;
        }
        if (name == PropertyName.@_fieldGodotResourceTexture) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Texture>(this.@_fieldGodotResourceTexture);
            return true;
        }
        if (name == PropertyName.@_fieldGodotResourceTextureWithInitializer) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Texture>(this.@_fieldGodotResourceTextureWithInitializer);
            return true;
        }
        if (name == PropertyName.@_fieldStringName) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.StringName>(this.@_fieldStringName);
            return true;
        }
        if (name == PropertyName.@_fieldNodePath) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.NodePath>(this.@_fieldNodePath);
            return true;
        }
        if (name == PropertyName.@_fieldRid) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Rid>(this.@_fieldRid);
            return true;
        }
        if (name == PropertyName.@_fieldGodotDictionary) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Collections.Dictionary>(this.@_fieldGodotDictionary);
            return true;
        }
        if (name == PropertyName.@_fieldGodotArray) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Collections.Array>(this.@_fieldGodotArray);
            return true;
        }
        if (name == PropertyName.@_fieldGodotGenericDictionary) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFromDictionary(this.@_fieldGodotGenericDictionary);
            return true;
        }
        if (name == PropertyName.@_fieldGodotGenericArray) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFromArray(this.@_fieldGodotGenericArray);
            return true;
        }
        if (name == PropertyName.@_fieldEmptyInt64Array) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<long[]>(this.@_fieldEmptyInt64Array);
            return true;
        }
        return base.GetGodotClassPropertyValue(name, out value);
    }
    /// <summary>
    /// Get the property information for all the properties declared in this class.
    /// This method is used by Godot to register the available properties in the editor.
    /// Do not call this method.
    /// </summary>
    [global::System.ComponentModel.EditorBrowsable(global::System.ComponentModel.EditorBrowsableState.Never)]
    internal new static global::System.Collections.Generic.List<global::Godot.Bridge.PropertyInfo> GetGodotPropertyList()
    {
        var properties = new global::System.Collections.Generic.List<global::Godot.Bridge.PropertyInfo>();
        properties.Add(new(type: (global::Godot.Variant.Type)1, name: PropertyName.@_fieldBoolean, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)2, name: PropertyName.@_fieldChar, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)2, name: PropertyName.@_fieldSByte, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)2, name: PropertyName.@_fieldInt16, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)2, name: PropertyName.@_fieldInt32, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)2, name: PropertyName.@_fieldInt64, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)2, name: PropertyName.@_fieldByte, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)2, name: PropertyName.@_fieldUInt16, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)2, name: PropertyName.@_fieldUInt32, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)2, name: PropertyName.@_fieldUInt64, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)3, name: PropertyName.@_fieldSingle, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)3, name: PropertyName.@_fieldDouble, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)4, name: PropertyName.@_fieldString, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)3, name: PropertyName.@_fieldStaticImport, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)5, name: PropertyName.@_fieldVector2, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)6, name: PropertyName.@_fieldVector2I, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)7, name: PropertyName.@_fieldRect2, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)8, name: PropertyName.@_fieldRect2I, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)11, name: PropertyName.@_fieldTransform2D, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)9, name: PropertyName.@_fieldVector3, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)10, name: PropertyName.@_fieldVector3I, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)17, name: PropertyName.@_fieldBasis, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)15, name: PropertyName.@_fieldQuaternion, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)18, name: PropertyName.@_fieldTransform3D, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)12, name: PropertyName.@_fieldVector4, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)13, name: PropertyName.@_fieldVector4I, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)19, name: PropertyName.@_fieldProjection, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)16, name: PropertyName.@_fieldAabb, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)20, name: PropertyName.@_fieldColor, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)14, name: PropertyName.@_fieldPlane, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)25, name: PropertyName.@_fieldCallable, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)26, name: PropertyName.@_fieldSignal, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)2, name: PropertyName.@_fieldEnum, hint: (global::Godot.PropertyHint)2, hintString: "A,B,C", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)2, name: PropertyName.@_fieldFlagsEnum, hint: (global::Godot.PropertyHint)6, hintString: "A:0,B:1,C:2", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)29, name: PropertyName.@_fieldByteArray, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)30, name: PropertyName.@_fieldInt32Array, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)31, name: PropertyName.@_fieldInt64Array, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)32, name: PropertyName.@_fieldSingleArray, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)33, name: PropertyName.@_fieldDoubleArray, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)34, name: PropertyName.@_fieldStringArray, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)34, name: PropertyName.@_fieldStringArrayEnum, hint: (global::Godot.PropertyHint)23, hintString: "4/2:A,B,C", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)35, name: PropertyName.@_fieldVector2Array, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)36, name: PropertyName.@_fieldVector3Array, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)37, name: PropertyName.@_fieldColorArray, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)28, name: PropertyName.@_fieldGodotObjectOrDerivedArray, hint: (global::Godot.PropertyHint)23, hintString: "24/0:", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)28, name: PropertyName.@_fieldStringNameArray, hint: (global::Godot.PropertyHint)23, hintString: "21/0:", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)28, name: PropertyName.@_fieldNodePathArray, hint: (global::Godot.PropertyHint)23, hintString: "22/0:", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)28, name: PropertyName.@_fieldRidArray, hint: (global::Godot.PropertyHint)23, hintString: "23/0:", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)30, name: PropertyName.@_fieldEmptyInt32Array, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)30, name: PropertyName.@_fieldArrayFromList, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)0, name: PropertyName.@_fieldVariant, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)135174, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)24, name: PropertyName.@_fieldGodotObjectOrDerived, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)24, name: PropertyName.@_fieldGodotResourceTexture, hint: (global::Godot.PropertyHint)17, hintString: "Texture", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)24, name: PropertyName.@_fieldGodotResourceTextureWithInitializer, hint: (global::Godot.PropertyHint)17, hintString: "Texture", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)21, name: PropertyName.@_fieldStringName, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)22, name: PropertyName.@_fieldNodePath, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)23, name: PropertyName.@_fieldRid, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)27, name: PropertyName.@_fieldGodotDictionary, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)28, name: PropertyName.@_fieldGodotArray, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)27, name: PropertyName.@_fieldGodotGenericDictionary, hint: (global::Godot.PropertyHint)23, hintString: "4/0:;1/0:", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)28, name: PropertyName.@_fieldGodotGenericArray, hint: (global::Godot.PropertyHint)23, hintString: "2/0:", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)31, name: PropertyName.@_fieldEmptyInt64Array, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        return properties;
    }
#pragma warning restore CS0109
}
